.. _help:

Help and support
================

If you encounter issues with the software or have any questions, please feel free to open a new issue on the `GitHub repository <https://github.com/DKFZ-OpenMedPhys/SupPy/issues>`_ or reach out via email.

Contact
-------

- `Email <t.becher@dkfz-heidelberg.de>`_
- `GitHub <https://github.com/DKFZ-OpenMedPhys/SupPy>`_
- `LinkedIn <https://www.linkedin.com/in/tobias-becher-877b93224/>`_


Funding and Development
-------------------------
*SupPy* was developed as part of the German-Israeli Cooperation in Cancer Research (Project Ca 216)
Responsible for SupPy are:

- Tobias Becher (DKFZ, Lead Developer & Research Fellow)
- Prof. Yair Censor (University of Haifa, Principal Investigator / Scientific Lead)
- Dr. Niklas Wahl (DKFZ, Principal Investigator / Scientific Lead)

.. image:: https://raw.githubusercontent.com/e0404/matRad/98ba2fb8b07f727a3963cf2572c82a548444580b/matRad/gfx/dkfz_logo_blue.png
    :align: right
    :width: 200px
